import fetch from 'isomorphic-fetch';

const opts = {
  beforeSend: (result) => result.json()
};

function index(url, opt) {
  return new Promise(async (resolve) => {
    const result = await fetch(url, opt);
    
    resolve(opts.beforeSend(result));
  });
}

async function $fetch(url, option = {}) {
  return index(url, option);
}

async function $get(url) {
  const getOpts = Object.assign({
    method: 'GET'
  }, opts);
  return await index(`${url}?t=${+new Date()}`, getOpts);
}

async function $post(url, data) {
  const postOpts = Object.assign({
    method: 'POST'
  }, opts);
  if (data) {
    postOpts.body = JSON.stringify(data);
  }
  return await index(url, postOpts);
}

export default {
  fetch: $fetch,
  get: $get,
  post: $post,
  install: (Vue, options) => {
    Object.assign(opts, options);
    Vue.mixin({
      methods: {
        $fetch,
        $get,
        $post
      }
    });
  }
};
